==> aexpy-0.1.2-py3-none-any.whl: aexpy/extracting/kwargs.py <==
from abc import abstractmethod
from pathlib import Path
from aexpy.extracting.enriching.callgraph import Callgraph

from aexpy.models import ApiDescription, Distribution
from aexpy.models.description import FunctionEntry

from .third.mypyserver import MypyBasedIncrementalExtractor, PackageMypyServer


class KwargsExtractor(MypyBasedIncrementalExtractor):
    def basicProduce(self, dist: "Distribution", product: "ApiDescription"):
        self.services.extract("attrs", dist, product=product)

    def enrichCallgraph(self, product: "ApiDescription", cg: "Callgraph"):
        callees: "dict[str, set[str]]" = {}

        for caller in cg.items.values():
            cur = set()
            for site in caller.sites:
                for target in site.targets:
                    cur.add(target)
            callees[caller.id] = cur

        for key, value in callees.items():
            entry = product.entries.get(key)
            if not isinstance(entry, FunctionEntry):
                continue
            entry.callees = list(value)
        
        product.calcCallers()

    def processWithMypy(self, server: "PackageMypyServer", product: "ApiDescription", dist: "Distribution"):
        from .enriching import kwargs

        product.clearCache()

        from .enriching.callgraph.type import TypeCallgraphBuilder
        cg = TypeCallgraphBuilder(server, self.logger).build(product)
        self.enrichCallgraph(product, cg)
        kwargs.KwargsEnricher(cg, self.logger).enrich(product)

        product.clearCache()

    def processWithFallback(self, product: "ApiDescription", dist: "Distribution"):
        from .enriching import kwargs

        product.clearCache()

        from .enriching.callgraph.basic import BasicCallgraphBuilder
        cg = BasicCallgraphBuilder(self.logger).build(product)
        self.enrichCallgraph(product, cg)
        kwargs.KwargsEnricher(Callgraph(), self.logger).enrich(product)

        product.clearCache()

==> aexpy-0.2.1-py3-none-any.whl: aexpy/extracting/kwargs.py <==
from typing import override
from aexpy.extracting.enriching.callgraph import Callgraph

from aexpy.models import ApiDescription
from aexpy.models.description import FunctionEntry

from .third.mypyserver import MypyExtractor


class KwargsExtractor(MypyExtractor):
    def enrichCallgraph(self, product: ApiDescription, cg: Callgraph):
        callees: dict[str, set[str]] = {}

        for caller in cg.items.values():
            cur = set()
            for site in caller.sites:
                for target in site.targets:
                    cur.add(target)
            callees[caller.id] = cur

        for key, value in callees.items():
            entry = product.entries.get(key)
            if not isinstance(entry, FunctionEntry):
                continue
            entry.callees = list(value)

        product.calcCallers()

    @override
    def process(self, server, product, dist):
        from .enriching import kwargs

        product.clearCache()
        from .enriching.callgraph.type import TypeCallgraphBuilder

        cg = TypeCallgraphBuilder(server, self.logger).build(product)
        self.enrichCallgraph(product, cg)
        kwargs.KwargsEnricher(cg, self.logger).enrich(product)

        product.clearCache()

    @override
    def fallback(self, product, dist):
        from .enriching import kwargs

        product.clearCache()
        from .enriching.callgraph.basic import BasicCallgraphBuilder

        cg = BasicCallgraphBuilder(self.logger).build(product)
        self.enrichCallgraph(product, cg)
        kwargs.KwargsEnricher(Callgraph(), self.logger).enrich(product)
        product.clearCache()
